@@ -741,6 +741,21 @@ pyerl_size(PyObject *self, PyObject *args)
 	return Py_BuildValue("i", ret);
 }
 
+static PyObject *
+pyerl_eterm_release(PyObject *self, PyObject *args)
+{
+	erl_eterm_release();
+	Py_RETURN_NONE;
+}
+
+static PyObject *
+pyerl_eterm_statistics(PyObject *self, PyObject *args)
+{
+	unsigned long allocated;
+	unsigned long freed;
+	erl_eterm_statistics(&allocated, &freed);
+	return Py_BuildValue("(kk)", allocated, freed);
+}
 
 static PyMethodDef methods[] = {
 	{"init", pyerl_init, METH_VARARGS,
@@ -790,6 +805,8 @@ static PyMethodDef methods[] = {
 	{"print_term", pyerl_print_term, METH_VARARGS, NULL},
 	{"size", pyerl_size, METH_VARARGS, NULL},
 
+	{"eterm_release", pyerl_eterm_release, METH_NOARGS, NULL},
+	{"eterm_statistics", pyerl_eterm_statistics, METH_NOARGS, NULL},
 	{NULL, NULL}
 };
 
